==> ejc-middlemeasurement-impl-3.0.0-20220412.090131-33-sources.jar: com/ejianc/business/middlemeasurement/vo/DesignsubcontractnodeVO.java <==
package com.ejianc.business.middlemeasurement.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.middlemeasurement.vo.DesignsubcontractnodedetailVO;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 设计分包节点报量申请
 * 
 * @author generator
 * 
 */
public class DesignsubcontractnodeVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date settlementDate; // 结算日期 
    private java.lang.String settlementCode; // 结算编号 
    private java.lang.Long contract; // 合同
    private java.lang.String contractName; // 合同名称
    private java.lang.String contractCode; // 合同编号
    private java.lang.Long designUnits; // 设计单位
    private java.lang.String designUnitsName; // 设计单位名称
    private java.lang.String designContent; // 设计内容
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date startDate; // 开始日期
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date endDate; // 截止时间
    private java.lang.Integer progressSettlementTimes; // 进度结算次数
    private java.lang.String imageCompletionSite; // 完成形象部位 
    private java.lang.String phone; // 联系电话 
    private java.math.BigDecimal excludingTaxPrice; // 不含税金额
    private java.math.BigDecimal tax; // 税金
    private java.math.BigDecimal taxPriceTotal; // 价税合计
    private java.lang.String scheduleConfirm; // 成功确认及设计进度确认（设计总负责人）
    private java.lang.String quality; // 质量（设计总负责人）
    private java.lang.String deductions; // 各种扣款项（商务工程师）
    private java.lang.String verifyAndOther; // 核实以上及其他相关工作（项目分管副总）
    private java.lang.String verifyQuantities; // 核实本次确认工程量、各部门奖罚、转扣或分摊费用等。（项目商务经理）

    private java.lang.String sort;
    private java.lang.String billStateStr;

    
    private List<DesignsubcontractnodedetailVO> designsubcontractnodedetailVos = new ArrayList<>(); // 设计分包节点报量申请子表


    public String getBillStateStr() {
        return billStateStr;
    }

    public void setBillStateStr(String billStateStr) {
        this.billStateStr = billStateStr;
    }

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 结算日期 
     */
    public java.util.Date getSettlementDate() {
        return settlementDate;
    }

    /**
     * 结算日期 
     */
    public void setSettlementDate(java.util.Date settlementDate) {
        this.settlementDate = settlementDate;
    }
    /**
     * 结算编号 
     */
    public java.lang.String getSettlementCode() {
        return settlementCode;
    }

    /**
     * 结算编号 
     */
    public void setSettlementCode(java.lang.String settlementCode) {
        this.settlementCode = settlementCode;
    }
    /**
     * 合同
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-outcontract")
    public java.lang.Long getContract() {
        return contract;
    }

    /**
     * 合同
     */
    @ReferDeserialTransfer
    public void setContract(java.lang.Long contract) {
        this.contract = contract;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 合同编号
     */
    public java.lang.String getContractCode() {
        return contractCode;
    }

    /**
     * 合同编号
     */
    public void setContractCode(java.lang.String contractCode) {
        this.contractCode = contractCode;
    }
    /**
     * 设计单位
     */
    @ReferSerialTransfer(referCode = "support-supplier")
    public java.lang.Long getDesignUnits() {
        return designUnits;
    }

    /**
     * 设计单位
     */
    @ReferDeserialTransfer
    public void setDesignUnits(java.lang.Long designUnits) {
        this.designUnits = designUnits;
    }
    /**
     * 设计单位名称
     */

    public java.lang.String getDesignUnitsName() {
        return designUnitsName;
    }

    /**
     * 设计单位名称
     */

    public void setDesignUnitsName(java.lang.String designUnitsName) {
        this.designUnitsName = designUnitsName;
    }
    /**
     * 设计内容
     */
    public java.lang.String getDesignContent() {
        return designContent;
    }

    /**
     * 设计内容
     */
    public void setDesignContent(java.lang.String designContent) {
        this.designContent = designContent;
    }
    /**
     * 开始日期
     */
    public java.util.Date getStartDate() {
        return startDate;
    }

    /**
     * 开始日期
     */
    public void setStartDate(java.util.Date startDate) {
        this.startDate = startDate;
    }
    /**
     * 截止时间
     */
    public java.util.Date getEndDate() {
        return endDate;
    }

    /**
     * 截止时间
     */
    public void setEndDate(java.util.Date endDate) {
        this.endDate = endDate;
    }
    /**
     * 进度结算次数
     */
    public java.lang.Integer getProgressSettlementTimes() {
        return progressSettlementTimes;
    }

    /**
     * 进度结算次数
     */
    public void setProgressSettlementTimes(java.lang.Integer progressSettlementTimes) {
        this.progressSettlementTimes = progressSettlementTimes;
    }
    /**
     * 完成形象部位 
     */
    public java.lang.String getImageCompletionSite() {
        return imageCompletionSite;
    }

    /**
     * 完成形象部位 
     */
    public void setImageCompletionSite(java.lang.String imageCompletionSite) {
        this.imageCompletionSite = imageCompletionSite;
    }
    /**
     * 联系电话 
     */
    public java.lang.String getPhone() {
        return phone;
    }

    /**
     * 联系电话 
     */
    public void setPhone(java.lang.String phone) {
        this.phone = phone;
    }
    /**
     * 不含税金额
     */
    public java.math.BigDecimal getExcludingTaxPrice() {
        return excludingTaxPrice;
    }

    /**
     * 不含税金额
     */
    public void setExcludingTaxPrice(java.math.BigDecimal excludingTaxPrice) {
        this.excludingTaxPrice = excludingTaxPrice;
    }
    /**
     * 税金
     */
    public java.math.BigDecimal getTax() {
        return tax;
    }

    /**
     * 税金
     */
    public void setTax(java.math.BigDecimal tax) {
        this.tax = tax;
    }
    /**
     * 价税合计
     */
    public java.math.BigDecimal getTaxPriceTotal() {
        return taxPriceTotal;
    }

    /**
     * 价税合计
     */
    public void setTaxPriceTotal(java.math.BigDecimal taxPriceTotal) {
        this.taxPriceTotal = taxPriceTotal;
    }
    /**
     * 成功确认及设计进度确认（设计总负责人）
     */
    public java.lang.String getScheduleConfirm() {
        return scheduleConfirm;
    }

    /**
     * 成功确认及设计进度确认（设计总负责人）
     */
    public void setScheduleConfirm(java.lang.String scheduleConfirm) {
        this.scheduleConfirm = scheduleConfirm;
    }
    /**
     * 质量（设计总负责人）
     */
    public java.lang.String getQuality() {
        return quality;
    }

    /**
     * 质量（设计总负责人）
     */
    public void setQuality(java.lang.String quality) {
        this.quality = quality;
    }
    /**
     * 各种扣款项（商务工程师）
     */
    public java.lang.String getDeductions() {
        return deductions;
    }

    /**
     * 各种扣款项（商务工程师）
     */
    public void setDeductions(java.lang.String deductions) {
        this.deductions = deductions;
    }
    /**
     * 核实以上及其他相关工作（项目分管副总）
     */
    public java.lang.String getVerifyAndOther() {
        return verifyAndOther;
    }

    /**
     * 核实以上及其他相关工作（项目分管副总）
     */
    public void setVerifyAndOther(java.lang.String verifyAndOther) {
        this.verifyAndOther = verifyAndOther;
    }
    /**
     * 核实本次确认工程量、各部门奖罚、转扣或分摊费用等。（项目商务经理）
     */
    public java.lang.String getVerifyQuantities() {
        return verifyQuantities;
    }

    /**
     * 核实本次确认工程量、各部门奖罚、转扣或分摊费用等。（项目商务经理）
     */
    public void setVerifyQuantities(java.lang.String verifyQuantities) {
        this.verifyQuantities = verifyQuantities;
    }
    
     /**
      * 设计分包节点报量申请子表
      */
     public List<DesignsubcontractnodedetailVO> getDesignsubcontractnodedetailVos() {
        return designsubcontractnodedetailVos;
     }

     /**
      * 设计分包节点报量申请子表
      */
     public void setDesignsubcontractnodedetailVos(List<DesignsubcontractnodedetailVO> designsubcontractnodedetailVos) {
        this.designsubcontractnodedetailVos = designsubcontractnodedetailVos;
     }
}

==> ejc-middlemeasurement-impl-3.0.0-20221021.114700-173-sources.jar: com/ejianc/business/middlemeasurement/vo/DesignsubcontractnodeVO.java <==
package com.ejianc.business.middlemeasurement.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.middlemeasurement.vo.DesignsubcontractnodedetailVO;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 设计分包节点报量申请
 * 
 * @author generator
 * 
 */
public class DesignsubcontractnodeVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date settlementDate; // 结算日期 
    private java.lang.String settlementCode; // 结算编号 
    private java.lang.Long contract; // 合同
    private java.lang.String contractName; // 合同名称
    private java.lang.String contractCode; // 合同编号
    private java.lang.Long designUnits; // 设计单位
    private java.lang.String designUnitsName; // 设计单位名称
    private java.lang.String designContent; // 设计内容
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date startDate; // 开始日期
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date endDate; // 截止时间
    private java.lang.Integer progressSettlementTimes; // 进度结算次数
    private java.lang.String imageCompletionSite; // 完成形象部位 
    private java.lang.String phone; // 联系电话 
    private java.math.BigDecimal excludingTaxPrice; // 不含税金额
    private java.math.BigDecimal tax; // 税金
    private java.math.BigDecimal taxPriceTotal; // 价税合计
    private java.lang.String scheduleConfirm; // 成功确认及设计进度确认（设计总负责人）
    private java.lang.String quality; // 质量（设计总负责人）
    private java.lang.String deductions; // 各种扣款项（商务工程师）
    private java.lang.String verifyAndOther; // 核实以上及其他相关工作（项目分管副总）
    private java.lang.String verifyQuantities; // 核实本次确认工程量、各部门奖罚、转扣或分摊费用等。（项目商务经理）

    private java.lang.String sort;
    private java.lang.String billStateStr;

    
    private List<DesignsubcontractnodedetailVO> designsubcontractnodedetailEntities = new ArrayList<>(); // 设计分包节点报量申请子表


    public String getBillStateStr() {
        return billStateStr;
    }

    public void setBillStateStr(String billStateStr) {
        this.billStateStr = billStateStr;
    }

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 结算日期 
     */
    public java.util.Date getSettlementDate() {
        return settlementDate;
    }

    /**
     * 结算日期 
     */
    public void setSettlementDate(java.util.Date settlementDate) {
        this.settlementDate = settlementDate;
    }
    /**
     * 结算编号 
     */
    public java.lang.String getSettlementCode() {
        return settlementCode;
    }

    /**
     * 结算编号 
     */
    public void setSettlementCode(java.lang.String settlementCode) {
        this.settlementCode = settlementCode;
    }
    /**
     * 合同
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-outcontract")
    public java.lang.Long getContract() {
        return contract;
    }

    /**
     * 合同
     */
    @ReferDeserialTransfer
    public void setContract(java.lang.Long contract) {
        this.contract = contract;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 合同编号
     */
    public java.lang.String getContractCode() {
        return contractCode;
    }

    /**
     * 合同编号
     */
    public void setContractCode(java.lang.String contractCode) {
        this.contractCode = contractCode;
    }
    /**
     * 设计单位
     */
    @ReferSerialTransfer(referCode = "support-supplier")
    public java.lang.Long getDesignUnits() {
        return designUnits;
    }

    /**
     * 设计单位
     */
    @ReferDeserialTransfer
    public void setDesignUnits(java.lang.Long designUnits) {
        this.designUnits = designUnits;
    }
    /**
     * 设计单位名称
     */

    public java.lang.String getDesignUnitsName() {
        return designUnitsName;
    }

    /**
     * 设计单位名称
     */

    public void setDesignUnitsName(java.lang.String designUnitsName) {
        this.designUnitsName = designUnitsName;
    }
    /**
     * 设计内容
     */
    public java.lang.String getDesignContent() {
        return designContent;
    }

    /**
     * 设计内容
     */
    public void setDesignContent(java.lang.String designContent) {
        this.designContent = designContent;
    }
    /**
     * 开始日期
     */
    public java.util.Date getStartDate() {
        return startDate;
    }

    /**
     * 开始日期
     */
    public void setStartDate(java.util.Date startDate) {
        this.startDate = startDate;
    }
    /**
     * 截止时间
     */
    public java.util.Date getEndDate() {
        return endDate;
    }

    /**
     * 截止时间
     */
    public void setEndDate(java.util.Date endDate) {
        this.endDate = endDate;
    }
    /**
     * 进度结算次数
     */
    public java.lang.Integer getProgressSettlementTimes() {
        return progressSettlementTimes;
    }

    /**
     * 进度结算次数
     */
    public void setProgressSettlementTimes(java.lang.Integer progressSettlementTimes) {
        this.progressSettlementTimes = progressSettlementTimes;
    }
    /**
     * 完成形象部位 
     */
    public java.lang.String getImageCompletionSite() {
        return imageCompletionSite;
    }

    /**
     * 完成形象部位 
     */
    public void setImageCompletionSite(java.lang.String imageCompletionSite) {
        this.imageCompletionSite = imageCompletionSite;
    }
    /**
     * 联系电话 
     */
    public java.lang.String getPhone() {
        return phone;
    }

    /**
     * 联系电话 
     */
    public void setPhone(java.lang.String phone) {
        this.phone = phone;
    }
    /**
     * 不含税金额
     */
    public java.math.BigDecimal getExcludingTaxPrice() {
        return excludingTaxPrice;
    }

    /**
     * 不含税金额
     */
    public void setExcludingTaxPrice(java.math.BigDecimal excludingTaxPrice) {
        this.excludingTaxPrice = excludingTaxPrice;
    }
    /**
     * 税金
     */
    public java.math.BigDecimal getTax() {
        return tax;
    }

    /**
     * 税金
     */
    public void setTax(java.math.BigDecimal tax) {
        this.tax = tax;
    }
    /**
     * 价税合计
     */
    public java.math.BigDecimal getTaxPriceTotal() {
        return taxPriceTotal;
    }

    /**
     * 价税合计
     */
    public void setTaxPriceTotal(java.math.BigDecimal taxPriceTotal) {
        this.taxPriceTotal = taxPriceTotal;
    }
    /**
     * 成功确认及设计进度确认（设计总负责人）
     */
    public java.lang.String getScheduleConfirm() {
        return scheduleConfirm;
    }

    /**
     * 成功确认及设计进度确认（设计总负责人）
     */
    public void setScheduleConfirm(java.lang.String scheduleConfirm) {
        this.scheduleConfirm = scheduleConfirm;
    }
    /**
     * 质量（设计总负责人）
     */
    public java.lang.String getQuality() {
        return quality;
    }

    /**
     * 质量（设计总负责人）
     */
    public void setQuality(java.lang.String quality) {
        this.quality = quality;
    }
    /**
     * 各种扣款项（商务工程师）
     */
    public java.lang.String getDeductions() {
        return deductions;
    }

    /**
     * 各种扣款项（商务工程师）
     */
    public void setDeductions(java.lang.String deductions) {
        this.deductions = deductions;
    }
    /**
     * 核实以上及其他相关工作（项目分管副总）
     */
    public java.lang.String getVerifyAndOther() {
        return verifyAndOther;
    }

    /**
     * 核实以上及其他相关工作（项目分管副总）
     */
    public void setVerifyAndOther(java.lang.String verifyAndOther) {
        this.verifyAndOther = verifyAndOther;
    }
    /**
     * 核实本次确认工程量、各部门奖罚、转扣或分摊费用等。（项目商务经理）
     */
    public java.lang.String getVerifyQuantities() {
        return verifyQuantities;
    }

    /**
     * 核实本次确认工程量、各部门奖罚、转扣或分摊费用等。（项目商务经理）
     */
    public void setVerifyQuantities(java.lang.String verifyQuantities) {
        this.verifyQuantities = verifyQuantities;
    }


    public List<DesignsubcontractnodedetailVO> getDesignsubcontractnodedetailEntities() {
        return designsubcontractnodedetailEntities;
    }

    public void setDesignsubcontractnodedetailEntities(List<DesignsubcontractnodedetailVO> designsubcontractnodedetailEntities) {
        this.designsubcontractnodedetailEntities = designsubcontractnodedetailEntities;
    }
}
